@@ -12,7 +12,7 @@ from typing import List, Tuple
 from concurrent.futures import ThreadPoolExecutor
 from multiprocessing import cpu_count
 
-from pytesstrain.text2image import run_text2image
+from pytesstrain.text2image import run_text2image, Text2imageNotFoundError, Text2imageError
 from pytesstrain.utils import setup_tesseract_path, default_fonts_dir
 
 RE_LINE_ENDING = re.compile('\r?\n')
@@ -38,7 +38,12 @@ def generate_image(gt_txt: Path, fonts_dir: Path, font: str, width: int):
     outputbase = gt_txt.with_suffix('').with_suffix('')  # Remove .gt.txt
     logging.debug('Generating {}'.format(outputbase.name))
     config = '--strip_unrenderable_words --xsize {} --ysize 300 --leading 32 --margin 12'.format(width)
-    run_text2image(str(gt_txt), str(outputbase), str(fonts_dir), font, exposure=0, config=config)
+    try:
+        run_text2image(str(gt_txt), str(outputbase), str(fonts_dir), font, exposure=0, config=config)
+    except Text2imageNotFoundError:
+        logging.error('Could not find text2image')
+    except Text2imageError as error:
+        logging.error('text2image: {message} (return code: {code})'.format(message=error.message, code=error.status))
     if not outputbase.with_suffix(outputbase.suffix + '.tif').exists():  # Ensure that only renderable .gt.txt exist
         logging.warning('File {} is unrenderable! Removing it...'.format(gt_txt))
         gt_txt.unlink()
